@@ -24,11 +24,9 @@ import (
 	"fmt"
 	"log"
 	"os"
-	"os/signal"
 	"regexp"
 	"strconv"
 	"sync"
-	"syscall"
 )
 
 const (
@@ -170,20 +168,6 @@ func jsInit() {
 		jsTokens[jsToken]++
 		jsRelease("ifchange entered", jsToken)
 	}
-
-	killed := make(chan os.Signal, 0)
-	signal.Notify(killed, syscall.SIGTERM, syscall.SIGINT)
-	go func() {
-		<-killed
-		jsTokensM.Lock()
-		for token, i := range jsTokens {
-			for ; i > 0; i-- {
-				jsReleaseNoLock(token)
-			}
-		}
-		jsTokensM.Unlock()
-		os.Exit(1)
-	}()
 }
 
 func jsReleaseNoLock(token byte) {
@@ -203,6 +187,16 @@ func jsRelease(ctx string, token byte) {
 	jsTokensM.Unlock()
 }
 
+func jsReleaseAll() {
+	jsTokensM.Lock()
+	for token, i := range jsTokens {
+		for ; i > 0; i-- {
+			jsReleaseNoLock(token)
+		}
+	}
+	jsTokensM.Unlock()
+}
+
 func jsAcquire(ctx string) byte {
 	if JSR == nil {
 		return BMakeGoodToken
